import { formatDateToMonthDayYear } from "@/lib/utils";
import { Announcement } from "@/lib/types";
import { fetchAnnouncements } from "@/lib/api";
import { markdownToHtml } from "@/lib/utils";
import Link from "next/link";

export const metadata = {
    title: "Announcement Page",
    description: "NullTranslationGroup Announcement Page",
};

export default async function AnnouncementPage() {
    let announcements: Announcement[] = [];
    try {
        announcements = await fetchAnnouncements();
        for (const announcement of announcements) {
            announcement.content = await markdownToHtml(announcement.content);
          }
    } catch (error) {
        console.error(error);
        return (
            <div className="text-center mt-10 text-red-500">
                <p>Failed to load announcements. Please try again later.</p>
            </div>
        );
    }

    // Sort announcements by date (newest first)
    const sorted_announcements: Announcement[] = announcements.sort(
        (a, b) => new Date(b.datetime).getTime() - new Date(a.datetime).getTime()
    );
    return (
        <div className="max-w-6xl mx-auto py-10 px-4">
            <h1 className="text-3xl font-bold text-center mb-8">Announcements</h1>
            {sorted_announcements.length === 0 ? (
                <div className="text-center text-gray-500">
                    <p>No announcements available.</p>
                </div>
            ) : (
                <div className="space-y-6">
                    {sorted_announcements.map((announcement) => {
                        const contents = announcement.content.split("\n");
                        announcement.content = contents.length > 3 ? contents.slice(0, 3).join("\n") : announcement.content;
                        return (
                            <Link
                                href={`/announcements/${announcement.documentId}`}
                                key={announcement.documentId}
                            >
                                <div className="prose dark:prose-invert max-w-none p-6 bg-white shadow-md rounded-lg cursor-pointer transition-colors duration-300 hover:shadow-lg dark:bg-gray-800 dark:shadow-gray-900">
                                    <div className="text-sm text-gray-500 mb-4 dark:text-gray-400">
                                        {formatDateToMonthDayYear(new Date(announcement.datetime))}
                                    </div>
                                    <div
                                        className="text-gray-700 mb-4 dark:text-gray-300 prose dark:prose-invert max-w-none"
                                        dangerouslySetInnerHTML={{ __html: announcement.content }}
                                    />
                                    <div className="flex items-center text-blue-600 hover:text-blue-800 transition-colors duration-300 dark:text-blue-400 dark:hover:text-blue-300">
                                        <span className="mr-2">Read More</span>
                                    </div>
                                </div>
                            </Link>
                        )
                    })}
                </div>
            )}
        </div>
    );
}