
import { NextResponse } from 'next/server';

export async function POST(request: Request) {
  try {
    const API_URL = process.env.NEXT_PUBLIC_API_URL;
    const API_TOKEN = process.env.STRAPI_API_TOKEN;

    const body = await request.json();

    if (!API_URL || !API_TOKEN) {
      return NextResponse.json({ message: 'Server configuration error' }, {status: 500});
    }
    try {
      const response = await fetch(`${API_URL}/api/reports`, {
        method: 'POST',
        headers: {
          Authorization: `Bearer ${API_TOKEN}`,
          'Content-Type': 'application/json',
        },
        body: JSON.stringify(body),
      });

      const data = await response.json();

      if (!response.ok) {
        return NextResponse.json({ error: data }, { status: response.status });
      }

      return NextResponse.json({data: data}, {status: response.status});
    } catch (error: any) {
      NextResponse.json({message: 'Going to server error', error: error.message})
    }
  } catch (error: any) {
    console.error('Error handling request:', error);
    return NextResponse.json({ message: 'Internal Server Error', error: error.message }, { status: 500 });
  }
}
