import React from "react";
import GlossaryPopup from "./GlossaryPopup";
import parse, { DOMNode, Element } from "html-react-parser";

interface ChapterRendererProps {
  content: string;
  glossary: JSON;
}

const ChapterRenderer: React.FC<ChapterRendererProps> = ({ content, glossary }) => {
  // Split content into lines
  const content_lines = content.split("\n");

  // Process each line for glossary replacement
  const processed_lines = content_lines.map((line) => {
    // Replace glossary terms in the line
    Object.entries(glossary).forEach(([term, definition]) => {
      const termRegex = new RegExp(`\\b${term}\\b`, "gi"); // Match whole word (case-insensitive)
      line = line.replace(termRegex, `<glossarypopup term="${term}" definition="${definition}"></glossarypopup>`);
    });

    line = line.replace(/<p>/g, "<div>").replace(/<\/p>/g, "</div>");

    return line;
  });

  return (
    <div>
      {processed_lines.map((line, index) => {
        if (!line.includes("<glossarypopup")) {
          return <div key={index} className="mb-4">{parse(line)}</div>;
        }
        return (
        <div key={index} className="mb-4">
          {parse(line, {
            replace: (domNode: DOMNode) => {
              if (domNode instanceof Element && domNode.tagName === "glossarypopup") {
                return (
                  <GlossaryPopup
                    term={domNode.attribs.term}
                    definition={domNode.attribs.definition}
                  />
                );
              }
              return domNode;
            },
          })}
        </div>
        )
    })}
    </div>
  );
};

export default ChapterRenderer;
