"use client"
import React, { useState, useRef } from "react";

interface ReportButtonProps {
    bookId: string;
    chapterId: string;
}
async function createReport(
    error_type: string,
    details: string,
    book_id: string,
    chapter_id: string,
) {
    const payload = {
        data:{
            error_type: error_type,
            details: details,
            book: book_id,
            chapter: chapter_id
        }
    }

    const response = await fetch(
        '/api/reports',
        {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify(payload)
        }
    )

    if(!response.ok) {
        throw new Error(`API request failed with status ${response.status}`)
    }
    return response.json()
}
const ReportButton: React.FC<ReportButtonProps> = ({ bookId, chapterId }) => {
    const modalRef = useRef<HTMLDivElement>(null)
    const [isOpen, setIsOpen] = useState(false)
    const [errorType, setErrorType] = useState('')
    const [details, setDetails] = useState('')
    const handleSubmitReport = (event: React.FormEvent<HTMLFormElement>) => {
        // Implement report submission here
        event.preventDefault()
        createReport(errorType,details,bookId,chapterId)
        setErrorType('')
        setDetails('')
        setIsOpen(false)
    }
    const handleExit = (event: React.MouseEvent) => {        
        setErrorType('')
        setDetails('')
        if (modalRef.current && !modalRef.current.contains(event.target as Node)) {
            setIsOpen(false)
        }
        event.stopPropagation()
    }
    return (
        <div className="flex justify-center pt-4"
            onClick={handleExit}>
            <button onClick={() => setIsOpen(true)} className="px-4 py-2 bg-red-600 text-white font-semibold rounded-lg shadow-md hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-red-400 focus:ring-offset-2"> Report </button>
            {isOpen && (<div className="fixed inset-0 z-50 flex items-center justify-center bg-black bg-opacity-50">
                <div
                    className="dark:bg-gray-800 bg-white w-11/12 md:w-1/2 lg:w-1/3 p-6 rounded-lg shadow-lg relative"
                    ref={modalRef}
                    onClick={(e) => e.stopPropagation()}>
                    <div className="flex justify-between items-center border-b pb-3">
                        <h3 className="text-lg font-semibold ">Report Chapter</h3>
                    </div>
                    <div className="mt-4">
                        <form className="p-6 rounded-lg max-w-md mx-auto space-y-4"
                            onSubmit={handleSubmitReport}>
                            <div>
                                <label className="block text-md font-semibold mb-1 dark:text-gray-300" htmlFor="error-type">
                                    Select Error Type :
                                </label>
                                <select
                                    id="error-type"
                                    className="block w-full border border-gray-300 dark:border-gray-600 dark:bg-gray-700 dark:text-gray-300 rounded-lg p-2 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-blue-500"                               
                                    value={errorType}
                                    onChange={(e)=> setErrorType(e.target.value)}
                                    >
                                    <option value="">Select your Type</option>
                                    <option value="Spelling Error">Spelling Error</option>
                                    <option value="Pronoun Error">Pronoun Error</option>
                                    <option value="Formatting Error">Formatting Error</option>
                                    <option value="Missing Content">Missing Content</option>
                                </select>
                            </div>

                            <div>
                                <label className="block text-md font-semibold mb-1" htmlFor="details">
                                    Additional Details :
                                </label>
                                <textarea
                                    id="details"
                                    placeholder="Provide additional details"
                                    value={details}
                                    onChange={(e) => setDetails(e.target.value)}
                                    className="block w-full h-24 border border-gray-300 dark:border-gray-600 dark:bg-gray-700 dark:text-gray-300 rounded-lg p-2 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-blue-500 resize-none overflow-y-auto"/>
                            </div>
                            <div className="flex justify-between">
                                <button
                                    type="submit"
                                    className="px-4 py-2 bg-green-500 text-white font-medium rounded-lg hover:bg-green-600 focus:outline-none focus:ring-2 focus:ring-blue-400 focus:ring-offset-2"
                                >
                                    Submit
                                </button>
                                <button
                                    onClick={handleExit}
                                    className="px-4 py-2 dark:bg-gray-500 bg-gray-200 rounded-lg hover:bg-gray-300"
                                >
                                    Close
                                </button>
                            </div>
                        </form>

                    </div>
                </div>
            </div>
            )}
        </div>
    );
}

export default ReportButton;